==========
User Guide
==========

General concepts and guides
===========================

.. toctree::
   :maxdepth: 2

   overview
   quickstart
   dashboard-user-guide
   features
   registering-image
   statuses
   sahara-on-ironic


Plugins
=======

.. toctree::
   :maxdepth: 2

   plugins


Elastic Data Processing
=======================

.. toctree::
   :maxdepth: 2

   edp
   edp-s3


Guest Images
============

.. toctree::
   :maxdepth: 2

   building-guest-images
   hadoop-swift
